# Effects of vertical spatial overlap on phytoplankton functional diversity under experimentally altered lake stratification regimes
# P. Le Noac'h, B. Beisner, V. Ouellet Jobin
# Corresponding author: le_noac_h.philippe@courrier.uqam.ca; ORCID: 0000-0001-8866-751X
# R script to produce results presented in Table 2 (permutated linear regression on functional trait diversity)

rm(list=ls(all=TRUE))

# Import required packages
library(tidyverse)
library(ape)

# Set working directory to datasets location
setwd("~/DataS1")

# Import the TIMEX phytoplankton biomasses dataset
DataBiom <- read_delim("Data_PhytoBiomasses_LeNoachetal.csv",delim=",")
DataBiom_g <- DataBiom %>% gather(key = "Taxa_abr",value="Biom",-ID)

# Import the TIMEX phytoplankton functional traits dataset
TraitMat <- read_delim("Data_FunctionalTraits_LeNoachetal.csv",delim=";") %>%
  dplyr::select(-c("Taxa","Groupe"))

# Import the main TIMEX dataset (same dataset used to estimate the SEMs)
# The three predictors needed are: Th_depth, meta_width, Cladocera & SO
Data_TIMEX <- read_delim("Data_SEM_LeNoachetal.csv",delim=",") %>%
  mutate(Date = as.character(Date)) %>%
  dplyr::select(Date,Basin,Thermo_Depth,Meta_Width,Cladocera_Biom,SO)


# Function to compute the diversity index for a specified categorical functional
# (based on the Shannon diversity index formula)
# takes two arguments:
# - the functional trait, i.e. any column name from the TraitMat dataframe except MLD (character string)
# - the name of the diversity index variable associated with the functional trait (character string)
DataBiom_HTrait_func <- function(Trait,H_trait_col){
  
  Data_BiomTrait <- DataBiom_g %>% full_join(TraitMat,by="Taxa_abr")
  
  colnames(Data_BiomTrait)[which(colnames(Data_BiomTrait)==Trait)] <- "Target_trait"
  
  DataBiom_HTrait <- Data_BiomTrait %>% group_by(ID,Target_trait) %>%
    summarize(Biom = sum(Biom)) %>%
    mutate(Biom_prop = Biom/sum(Biom)) %>%
    ungroup() %>%
    mutate(Date = substr(ID, 1, 10),Basin = as.numeric(substr(ID, 12,12))) %>%
    dplyr::select(-(ID)) %>%
    arrange(Date,Basin)  %>%
    filter(Biom_prop > 0) %>%
    mutate(plnp = Biom_prop*log(Biom_prop)) %>% 
    group_by(Date,Basin) %>%
    summarize(H_trait = - sum(plnp)) %>%
    ungroup()
  
  cols <- c("Date", "Basin","H_trait")
  new_cols <- c("Date", "Basin",H_trait_col)
  cols <- setNames(cols,new_cols)
  
  DataBiom_HTrait %>% rename_(.dots = cols)
}


# For the quantitative MLD trait, the diversity index variable is the Communuty Weighted standard error (as in Peres-Neto et al. 2017)
# First, compute the contribution of each taxa to the total biomass at each sampling events
DataBiom_MLD <- DataBiom %>% gather(key = "Taxa_abr",value="Biom",-ID) %>% 
  filter(Biom > 0) %>%
  group_by(ID) %>%
  mutate(Biom_sum = sum(Biom)) %>%
  mutate(Biom_prop = Biom/sum(Biom)) %>%
  ungroup() %>%
  arrange(ID)
# Second, compute the CWvar_MLD values from the taxa contributions to biomass and taxa MLD values 
DataBiom_CWvarMLD <- DataBiom_MLD %>% full_join(TraitMat,by="Taxa_abr") %>%
  mutate(Biomprop_MLD= Biom_prop*MLD) %>%
  group_by(ID) %>%
  mutate(CWmean_MLD = sum(Biomprop_MLD)) %>%
  ungroup() %>%
  mutate(CWvar_i = Biom_prop*((MLD-CWmean_MLD)^2)) %>%
  mutate(Date = substr(ID, 1, 10),Basin = as.numeric(substr(ID, 12,12))) %>%
  dplyr::select(-(ID)) %>%
  arrange(Date,Basin) %>% 
  group_by(Date,Basin) %>%
  summarize(CWvar_MLD = sum(CWvar_i)) %>%
  ungroup()

# Join the values of the 7 trait diversity variables into a single dataframe 
DataBiom_HTrait <- DataBiom_CWvarMLD %>%
  full_join(DataBiom_HTrait_func(Trait = "Nfix",H_trait_col = "H_nfix"),
            by = c("Date","Basin")) %>%
  full_join(DataBiom_HTrait_func(Trait = "Si",H_trait_col = "H_si"),
            by = c("Date","Basin")) %>%
  full_join(DataBiom_HTrait_func(Trait = "Mixotr",H_trait_col = "H_mix"),
            by = c("Date","Basin")) %>%
  full_join(DataBiom_HTrait_func(Trait = "Colony",H_trait_col = "H_col"),
            by = c("Date","Basin")) %>%
full_join(DataBiom_HTrait_func(Trait = "Pigment",H_trait_col = "H_pig"),
          by = c("Date","Basin"))

# Join the FT dataset with the predictor dataset
Data_lmperm <- full_join(DataBiom_HTrait,Data_TIMEX, by =c("Date","Basin"))


### Multiple permutated linear regressions

# Number of permutation (set to 10000)
nperm <- 10000

# Create the datasets where the results will be stored
res_multilmperm <- tibble(Resp=NA,Thermo_Depth=NA,
                                Meta_Width=NA,Cladocera_Biom=NA,SO=NA)

# Vector of trait (the column names of DataBiom_HTrait) over which the loop will iterate
TF_resp <- c("CWvar_MLD","H_nfix","H_si","H_mix","H_col","H_pig")

# Set the seed to reproduce the exact results of the paper (Table 2)
set.seed(1609)

# loop to estimate all six lmperm models
for(i in 1:length(TF_resp)){
  
  print(TF_resp[i])
  formula = paste0(TF_resp[i], " ~ Thermo_Depth + Meta_Width + Cladocera_Biom + SO")

  modlmperm_TF <- lmorigin(formula, data = Data_lmperm, origin=FALSE, nperm=nperm)
  # Get the coefficients of the model
  modlmperm_TF.coeff <- tibble(Resp=TF_resp[i],
                                Thermo_Depth=modlmperm_TF$reg$coefficients[2],
                                Meta_Width=modlmperm_TF$reg$coefficients[3],
                                Cladocera_Biom=modlmperm_TF$reg$coefficients[4],
                                SO=modlmperm_TF$reg$coefficients[5])
  # Get the p-values of the model (One-tailed tests of regression coefficients: test in the direction of the sign of the coefficient)
  modlmperm_TF.pv <- tibble(Resp=paste(TF_resp[i],".pv",sep=""),
                             Thermo_Depth=modlmperm_TF$p.perm.t.1tail[2],
                             Meta_Width=modlmperm_TF$p.perm.t.1tail[3],
                             Cladocera_Biom=modlmperm_TF$p.perm.t.1tail[4],
                             SO=modlmperm_TF$p.perm.t.1tail[5])
  
  # Add the coefficients and pvalues to the res_multilmperm results dataset
  res_multilmperm <- res_multilmperm %>%
    bind_rows(modlmperm_TF.coeff) %>%
    bind_rows(modlmperm_TF.pv)
}

# Remove the first row of the res_multilmperm dataset (empty initialization row)
res_multilmperm <- res_multilmperm[-1,]

# Create a file name to export the results
res_multilmperm_path <- paste(c("Res_MultivlmpermTraits_nperm=",nperm,".csv"),collapse="")
# Export the results (coefficient and pvalues)
write_delim(res_multilmperm,res_multilmperm_path,delim=",")