# Effects of vertical spatial overlap on phytoplankton diversity under experimentally altered lake stratification regimes
# P. Le Noac'h, B. Beisner, V. Ouellet Jobin
# Corresponding author: le_noac_h.philippe@courrier.uqam.ca; ORCID: 0000-0001-8866-751X
# R script to produce results presented in Figure 4 (SEMs)
# WARNING: this script takes several minutes to run to completion

rm(list=ls(all=TRUE))

# Import required packages
library(tidyverse)
library(lavaan)

# Set working directory to dataset location
setwd("~/DataS1")

# Data importation
Data <- read_delim("Data_SEM_LeNoachetal.csv",delim=",") %>%
   mutate(Date = as.character(Date)) %>%
   mutate(Cladocera_Biom = log(Cladocera_Biom)) # Transforming the variable Cladocera

### Specifying the SEMs

# 1) SEM for Taxonomic diversity (Shannon_H)
modSEM_TIMEX_H <-  '
      # paths
      SO ~ Thermo_Depth + Meta_Width
      Cladocera_Biom ~ Thermo_Depth + Meta_Width
      Shannon_H ~ Thermo_Depth + Meta_Width + SO + Cladocera_Biom
'

# 2) SEM for Functional diversity (FDis)
modSEM_TIMEX_FDis <- '
      # paths
      SO ~ Thermo_Depth + Meta_Width
      Cladocera_Biom ~ Thermo_Depth + Meta_Width
      FDis ~  Thermo_Depth + Meta_Width + SO + Cladocera_Biom
'

list_model <- list(modSEM_TIMEX_H,
                   modSEM_TIMEX_FDis,
                   c("ShannonH","FDis"))


# Number of boostrapped samples (set to 10000)
nboot <- 10000

# Loop that iterate ove the list of the model to estimate
for(i in 1:(length(list_model)-1)){

   mod_TIMEX <- list_model[[i]]
   Export_id <- list_model[[length(list_model)]][i]
   print(Export_id)
   
   # Fit the model (i.e. est. parameters)
   set.seed(1609) # set the seed to reproduce the exact results of the paper

   mod_TIMEX.fit <- sem(mod_TIMEX, data=Data, test="boot", se="boot", bootstrap=nboot)
   
   # StandCoeff_export: dataframe with the standardized path coefficients values (column est.std)
   # This dataframe also includes the p-values computed under Gaussian assumption (column pvalue)
   StandCoeff_export <- standardizedSolution(mod_TIMEX.fit, type = "std.all")
   
   # Pvalboot_export: dataframe with the bootstrapped pvalues (column pvalue)
   # This dataframe also includes the raw (unstandardized) path coefficient values (column est) and the standardized path coefficients values (column std.all)
   StandCoeffPvalboot_export <- parameterEstimates(mod_TIMEX.fit,standardized = TRUE)

   # sum_rsq_export: dataframe with the Rsquare values
   Rsq <- data.frame(lavInspect(mod_TIMEX.fit,what = "rsquare"))
   Rsq_export <- data.frame(Var=rownames(Rsq),Rsquare=Rsq$lavInspect.mod_TIMEX.fit..what....rsquare..)
   
   # FM_export: Additional metrics for the final model
   FM <- fitMeasures(mod_TIMEX.fit)
   FM_export <- data.frame(FM=rownames(data.frame(FM)),Value=data.frame(FM)$FM)
   
   ### Export the results
   ###  three dataframes per model :
   ###  - Bootstrapped pvalues and standardized coefficients (StandCoeffPvalboot_export)
   ###  - Rsquare values (Rsq_export)
   ###  - Fit metrics (FM_export)
   write_csv(StandCoeffPvalboot_export,paste(c("Res_SEM_",Export_id,"_TableStandardizedSolutionBoot_BSnboot=",nboot,".csv"),collapse=""))
   write_csv(Rsq_export,paste(c("Res_SEM_",Export_id,"_TableRsq_BSnboot=",nboot,".csv"),collapse=""))
   write_csv(FM_export,paste(c("Res_SEM_",Export_id,"_TableFitMeasures_BSnboot=",nboot,".csv"),collapse=""))
   
}