# Effects of vertical spatial overlap on phytoplankton diversity under experimentally altered lake stratification regimes
# P. Le Noac'h, B. Beisner, V. Ouellet Jobin
# Corresponding author: le_noac_h.philippe@courrier.uqam.ca; ORCID: 0000-0001-8866-751X
# R script to produce results presented in Figure S4: Bootstrapped linear regressions models of the metalimnion width over the prevalence of mixotrophy and cyanobacteria

rm(list=ls(all=TRUE))

# Import required packages
library(tidyverse)
library(boot)

# Set working directory to datasets location
setwd("~/DataS1")

### Importing the SEM dataset with the metalimnion width values
Data_MW <- read_delim("Data_SEM_LeNoachetal.csv",delim=",") %>%
  mutate(ID = paste(Date,Basin,sep="_")) %>%
  dplyr::select(ID,Meta_Width)
dim(Data_MW)
head(Data_MW)

### Importing the Functional trait matrix
data_TF <- read_delim("Data_FunctionalTraits_LeNoachetal.csv",delim=";")
# Select the columns for the taxa codes, the taxonomic groups and the trait mixotrophy
data_TF_red <- data_TF %>% dplyr::select(Taxa_abr,Mixotr,Groupe) %>%
  mutate(Mixotr = ifelse(Mixotr == "y",1,0),
         Cyano = ifelse(Groupe == "CYANO",1,0))
dim(data_TF_red)
head(data_TF_red)

### Importing the phytoplankton biomass dataset
data_phytoBIOM <- read_delim("Data_PhytoBiomasses_LeNoachetal.csv",delim=",")
length(table(data_phytoBIOM$ID))
# Reshape the biomass dataset to get one row per taxa per sampling event
data_phytoBIOM_g <- gather(data_phytoBIOM,key = "Taxa_abr",value = "BIOM",-ID)
# Compute the total biomass at each sampling event
data_phytoBIOMtot <- data_phytoBIOM_g %>% 
  group_by(ID) %>%
  summarize(BIOMtot = sum(BIOM)) %>%
  ungroup()

### 1) Join the total biomass at each sampling event to the reshaped biomass dataset
### 2) From the raw biomasses, compute the contribution to the total biomass for each taxa at each sampling event
### 3) Create new columns to set the contribution of non-mixotrophs or non-cyanobacteria taxa to 0
### 4) Compute the total proportions of mixotrophs and cyanobacteria at each sampling event
data_contr <- full_join(data_TF_red,data_phytoBIOM_g,by ="Taxa_abr") %>%
  full_join(data_phytoBIOMtot,by ="ID") %>%
  mutate(BIOMprop = BIOM/BIOMtot) %>%  
  mutate(MixotrBIOMprop = BIOMprop*Mixotr,
         CyanoBIOMprop = BIOMprop*Cyano) %>%
  group_by(ID) %>%
  summarize(propMixotr = sum(MixotrBIOMprop),
            propCyano = sum(CyanoBIOMprop)) %>%
  ungroup()

# Join the metalimnion width, the mixotrophic prevalence and the cyanobacteria prevalence in a single dataset
data_lm <- full_join(Data_MW,data_contr,by="ID") %>%
  mutate(propMixotr = propMixotr*100,
         propCyano = propCyano*100) # transform the proportions in percentages


# set the seed to reproduce the exact results of the paper
set.seed(1609)

# Number of bootstrapped samples for the bootstrap procedure (set to 10000)
nboot <- 10000

#######################################################################################
### Effect of metalimnion width on the prevalence of cyanobacteria in the community ### 
#######################################################################################

# Set up a function to bootstrap model prediction values in order to estimate the CI limits around the slope
func_lmbootCyano_CI = function(data,idx){
  predict(lm(propCyano~Meta_Width,data=data[idx,]),
          newdata = data.frame(Meta_Width=data_lm$Meta_Width))
}
# Set up a function to bootstrap the model slope p-value
func_lmbootCyano_pvalue = function(data,idx){
  (summary(lm(propCyano~Meta_Width,data=data[idx,]))$coefficients)[2,4]
}

# generate a bootstrapped distribution of model prediction and use this distribution to compute the limit of the 95% CI around the model slope
B_cyano <- boot(data_lm,func_lmbootCyano_CI,R=nboot)
CI95bands_lim_MWcyano <- data.frame(t(apply(B_cyano$t,2, quantile, c(0.025, 0.975))))
colnames(CI95bands_lim_MWcyano) <- c("CI_Inf","CI_Sup")

# Bootstrapp the p-value from the regression model for cyanobacteria prevalence
pvalueboot_cyano <- boot(data_lm,func_lmbootCyano_pvalue,R=nboot)
print(paste("Bootstrapped p-value of the regression model for cyanobacteria prevalence: ",mean(pvalueboot_cyano$t)))

# Get the coefficients from the regression model for cyanobacteria prevalence
coeff_MWcyano <- coefficients(lm(propCyano~Meta_Width,data=data_lm))

# plot the with the original regression model and the bootstrapped CI around the slope (Fig. S2b)
df_lmplot_MWcyano <- bind_cols(data_lm,CI95bands_lim_MWcyano)
p_MWcyano <- ggplot(df_lmplot_MWcyano, aes(x=Meta_Width, y=propCyano, ymin=CI_Inf, ymax=CI_Sup)) +
  geom_ribbon(fill="#CCCCCC") +
  xlim(1,10) +
  geom_abline(slope=coeff_MWcyano[2], intercept=coeff_MWcyano[1]) + 
  geom_line(aes(x=Meta_Width, y=CI_Inf),linetype=2) +
  geom_line(aes(x=Meta_Width, y=CI_Sup),linetype=2) +
  geom_point(aes(x=Meta_Width, y=propCyano)) + 
  xlab("Metalimnion width (m)") + ylab("Prevalence of cyanobacteria (%)") +
  theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank(),
        panel.background = element_blank(),text = element_text(size = 16),
        axis.line = element_line(colour = "black"),
        axis.text=element_text(size=12))
p_MWcyano


#####################################################################################
### Effect of metalimnion width on the prevalence of mixotrophy in the community ### 
#####################################################################################

# Set up a function to bootstrap model prediction values in order to estimate the CI limits around the slope
func_lmbootMixotr_CI = function(data,idx){
  predict(lm(propMixotr~Meta_Width,data=data[idx,]),
          newdata = data.frame(Meta_Width=data_lm$Meta_Width))
}
# Set up a function to bootstrap the model slope p-value
func_lmbootMixotr_pvalue = function(data,idx){
  (summary(lm(propMixotr~Meta_Width,data=data[idx,]))$coefficients)[2,4]
}

# generate a bootstrapped distribution of model prediction and use this distribution to compute the limit of the 95% CI around the model slope
preictboot_mixotr <- boot(data_lm,func_lmbootMixotr_CI,R=nboot)
CI95bands_lim_MWmixotr <- data.frame(t(apply(preictboot_mixotr$t,2, quantile, c(0.025, 0.975))))
colnames(CI95bands_lim_MWmixotr) <- c("CI_Inf","CI_Sup")

# generate a bootstrapped distribution of the model p-value and compute the mean (the bootstrapped p-value)
pvalueboot_mixotr <- boot(data_lm,func_lmbootMixotr_pvalue,R=nboot)
print(paste("Bootstrapped p-value of the regression model for mixotrophic prevalence: ",mean(pvalueboot_mixotr$t)))

# Get the coefficients from the regression model for mixotrophic prevalence
coeff_MWmixotr <- coefficients(lm(propMixotr~Meta_Width,data=data_lm))

# plot the with the original regression model and the bootstrapped CI around the slope (Fig. S2a)
df_lmplot_MWmixotr <- bind_cols(data_lm,CI95bands_lim_MWmixotr)
p_MWmixotr <- ggplot(df_lmplot_MWmixotr, aes(x=Meta_Width, y=propMixotr, ymin=CI_Inf, ymax=CI_Sup)) +
  geom_ribbon(fill="#CCCCCC") +
  xlim(1,10) +
  geom_abline(slope=coeff_MWmixotr[2], intercept=coeff_MWmixotr[1]) + 
  geom_line(aes(x=Meta_Width, y=CI_Inf),linetype=2) +
  geom_line(aes(x=Meta_Width, y=CI_Sup),linetype=2) +
  geom_point(aes(x=Meta_Width, y=propMixotr)) + 
  xlab("Metalimnion width (m)") + ylab("Prevalence of mixotrophy (%)") +
  theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank(),
        panel.background = element_blank(),text = element_text(size = 16),
        axis.line = element_line(colour = "black"),
        axis.text=element_text(size=12))
p_MWmixotr

### Export plots
ggsave("FigureS4a_MetaWidthMixotrophy.svg",p_MWmixotr,height=5,width=10)
ggsave("FigureS4b_MetaWidthCyanobacteria.svg",p_MWcyano,height=5,width=10)
